@@ -8,10 +8,7 @@ from .dag_factory_incremental import dag_factory_incremental_loading
 from copy import deepcopy
 
 import yaml
-try:
-    from yaml import CLoader as Loader, CDumper as Dumper
-except ImportError:
-    from yaml import Loader, Dumper
+from ewah.ewah_utils.yml_loader import Loader, Dumper
 
 def dags_from_dict(
     dag_definition,
@@ -132,7 +129,14 @@ def dags_from_dict(
 
     dwh_engines = {
         'postgres': EC.DWH_ENGINE_POSTGRES,
+        'Postgres': EC.DWH_ENGINE_POSTGRES,
         'snowflake': EC.DWH_ENGINE_SNOWFLAKE,
+        'Snowflake': EC.DWH_ENGINE_SNOWFLAKE,
+        EC.DWH_ENGINE_POSTGRES: EC.DWH_ENGINE_POSTGRES,
+        EC.DWH_ENGINE_SNOWFLAKE: EC.DWH_ENGINE_SNOWFLAKE,
+        # EC.DWH_ENGINE_BIGQUERY: EC.DWH_ENGINE_BIGQUERY,
+        # EC.DWH_ENGINE_REDSHIFT: EC.DWH_ENGINE_REDSHIFT,
+        # EC.DWH_ENGINE_S3: EC.DWH_ENGINE_S3,
         # 'bigquery': EC.DWH_ENGINE_BIGQUERY,
         # 'redshift': EC.DWH_ENGINE_REDSHIFT,
         # 's3': EC.DWH_ENGINE_S3,
@@ -142,6 +146,8 @@ def dags_from_dict(
         'fx': EWAHFXOperator,
         'ga': EWAHGAOperator,
         'google_analytics': EWAHGAOperator,
+        'gads': EWAHGoogleAdsOperator,
+        'google_ads': EWAHGoogleAdsOperator,
         'mysql': EWAHMySQLOperator,
         'oracle': EWAHOracleSQLOperator,
         'postgres': EWAHPostgresOperator,
@@ -155,6 +161,10 @@ def dags_from_dict(
         'gs': EWAHGSpreadOperator,
         'mongo': EWAHMongoDBOperator,
         'mongodb': EWAHMongoDBOperator,
+        'shopify': EWAHShopifyOperator,
+        'zendesk': EWAHZendeskOperator,
+        'gmaps': EWAHGMapsOperator,
+        'googlemaps': EWAHGMapsOperator,
     }
 
     allowed_dag_args = [
